@@ -4,19 +4,16 @@ use 5.006;
 use strict;
 use warnings;
 
-require Exporter;
-
-our @ISA = qw(Exporter);
+use base qw( WWW::Shorten::generic Exporter );
 our @EXPORT = qw(makeashorterlink makealongerlink);
-our ($VERSION) = q$Revision: 1.1 $ =~ /^ Revision: \s+ (\S+) \s+ $/x;
+our $VERSION = "1.81";
 
-use LWP;
 use Carp;
 
-sub makeashorterlink
+sub makeashorterlink ($)
 {
     my $url = shift or croak 'No URL passed to makeashorterlink';
-    my $ua = shift || LWP::UserAgent->new();;
+    my $ua = __PACKAGE__->ua();
     my $shorl = 'http://shorl.com/create.php';
     my $resp = $ua->post($shorl, [ url => $url ]);
     return unless $resp->is_success;
@@ -27,16 +24,21 @@ sub makeashorterlink
 	(\Qhttp://shorl.com/\E\w+)
 	</a>
 	<br>
+	[\r\n\s]*
+	\QPassword:\E
+	\s+
+	(\w+)
 	!x) {
-	return $1;
+	return wantarray ? ($1, $2) : $1;
     }
+    return;
 }
 
-sub makealongerlink
+sub makealongerlink ($)
 {
     my $shorl_url = shift 
 	or croak 'No Shorl key / URL passed to makealongerlink';
-    my $ua = shift || LWP::UserAgent->new(requests_redirectable => []);
+    my $ua = __PACKAGE__->ua();
 
     $shorl_url = "http://shorl.com/$shorl_url"
     unless $shorl_url =~ m!^http://!i;
@@ -65,6 +67,7 @@ WWW::Shorten::Shorl - Perl interface to shorl.com
   use WWW::Shorten 'Shorl';
 
   $short_url = makeashorterlink($long_url);
+  ($short_url,$password) = makeashorterlink($long_url);
 
   $long_url  = makealongerlink($short_url);
 
@@ -73,8 +76,9 @@ WWW::Shorten::Shorl - Perl interface to shorl.com
 A Perl interface to the web site shorl.com.  Shorl simply maintains
 a database of long URLs, each of which has a unique identifier.
 
-The function C<makeashorterlink> will call the Shorl web site passing
-it your long URL and will return the shorter Shorl version.
+The function C<makeashorterlink> will call the Shorl web site passing it
+your long URL and will return the shorter Shorl version. If used in a
+list context, then it will return both the Shorl URL and the password.
 
 The function C<makealongerlink> does the reverse. C<makealongerlink>
 will accept as an argument either the full Shorl URL or just the
@@ -88,22 +92,18 @@ Note that Shorl, unlike TinyURL and MakeAShorterLink, returns a unique code for
 
 makeashorterlink, makealongerlink
 
-=head1 TODO
-
-=over 4
-
-=item *
-
-Return the password somehow.
-
-=back
+=head1 BUGS, REQUESTS, COMMENTS
 
+Please report any requests, suggestions or bugs via the system at
+L<http://rt.cpan.org/>, or email E<lt>bug-WWW-Shorten@rt.cpan.orgE<gt>.
+This makes it much easier for me to track things and thus means
+your problem is less likely to be neglected.
 
 =head1 AUTHOR
 
 Iain Truskett <spoon@cpan.org>
 
-Based on WWW::MakeAShorteRLink by Dave Cross <dave@dave.org.uk>
+Based on WWW::MakeAShorterLink by Dave Cross <dave@dave.org.uk>
 
 =head1 SEE ALSO
 
